API docs for “spamfighter.utils.test.test_time.TestTimerTestCase”

# Class s.u.t.t.TestTimerTestCase(unittest.TestCase):

Part of spamfighter.utils.test.test_time View Source View In Hierarchy

Тесты на `spamfighter.utils.time` - таймер для тестов

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testStartUp | Undocumented
Method | testAdvance | Undocumented
Method | testSet | Undocumented
Method | testTearDown | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testStartUp(self): (source)
Undocumented
def testAdvance(self): (source)
Undocumented
def testSet(self): (source)
Undocumented
def testTearDown(self): (source)
Undocumented